/*	$NetBSD$	*/

/*-
 * Copyright (c) 2011 The NetBSD Foundation, Inc.
 * All rights reserved.
 *
 * This code is derived from software contributed to The NetBSD Foundation
 * by NONAKA Kimihiro.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef	UWSCONS_H_
#define	UWSCONS_H_

#include <sys/param.h>
#include <sys/types.h>
#include <sys/time.h>

#include <stdlib.h>
#include <string.h>
#include <stdarg.h>
#include <assert.h>

/* Fatal errors. */
#define	fatal(msg)	log_fatal("%s: %s", __func__, msg);
#define	fatalx(msg)	log_fatalx("%s: %s", __func__, msg);

/* log.c */
void log_open_tty(int);
void log_open_file(int, const char *);
void log_close(void);
void log_warn(const char *, ...) __printflike(1,2);
void log_warnx(const char *, ...) __printflike(1,2);
void log_info(const char *, ...) __printflike(1,2);
void log_debug(const char *, ...) __printflike(1,2);
void log_debug2(const char *, ...) __printflike(1,2);
__dead void log_fatal(const char *, ...) __printflike(1,2);
__dead void log_fatalx(const char *, ...) __printflike(1,2);
void log_vwarnx(const char *, va_list);
void log_vdebug(const char *, va_list);
__dead void log_vfatal(const char *, va_list);

/* wscons_glue.c */
__dead void panic(const char *, ...) __printflike(1,2);
void aprint_debug(const char *, ...) __printflike(1,2);
void aprint_error(const char *, ...) __printflike(1,2);

/* xmalloc.c */
char *xstrdup(const char *);
void *xcalloc(size_t, size_t);
void *xmalloc(size_t);
void *xrealloc(void *, size_t, size_t);
void xfree(void *);
int xasprintf(char **, const char *, ...) __printflike(2,3);
int xvasprintf(char **, const char *, va_list);
int xsnprintf(char *, size_t, const char *, ...) __printflike(3,4);
int xvsnprintf(char *, size_t, const char *, va_list);

#ifdef WSCONS_GLUE

#ifndef	min
#define	min(a,b)		((a) < (b) ? (a) : (b))
#endif
#ifndef	max
#define	max(a,b)		((a) > (b) ? (a) : (b))
#endif

#define	kmem_alloc(n,f)		xmalloc(n)
#define	kmem_zalloc(n,f)	xcalloc(1,n)
#define	kmem_free(p,n)		xfree(p)
#define	malloc(n,d,f)		xmalloc(n)
#define	free(p,d)		xfree(p)
#define	splhigh()		0
#define	splx(s)			/* Nothing to do */
#define	KASSERT(s)		assert(s)

/* for rasops */
#define	NRASOPS1		1
#define	NRASOPS2		1
#define	NRASOPS4		1
#define	NRASOPS8		1
#define	NRASOPS15		1
#define	NRASOPS16		1
#define	NRASOPS24		1
#define	NRASOPS32		1
#define	NRASOPS_ROTATION	1
#define	RASOPS_CLIPPING		1
#ifdef SMALLPROG
#define	RASOPS_SMALL
#endif

/* for wscons */
#define	WSDISPLAY_MULTILINGUAL
#define	WSEMUL_NO_DUMB
#define	WSEMUL_VT100

#ifndef	WS_DEFAULT_FG
#define	WS_DEFAULT_FG		WSCOL_WHITE
#endif
#ifndef	WS_DEFAULT_BG
#define	WS_DEFAULT_BG		WSCOL_BLACK
#endif
#ifndef	WS_DEFAULT_COLATTR
#define	WS_DEFAULT_COLATTR	0
#endif
#ifndef	WS_DEFAULT_MONOATTR
#define	WS_DEFAULT_MONOATTR	0
#endif
#ifndef	WS_KERNEL_FG
#define	WS_KERNEL_FG		WS_DEFAULT_FG
#endif
#ifndef	WS_KERNEL_BG
#define	WS_KERNEL_BG		WS_DEFAULT_BG
#endif
#ifndef	WS_KERNEL_COLATTR
#define	WS_KERNEL_COLATTR	WS_DEFAULT_COLATTR
#endif
#ifndef	WS_KERNEL_MONOATTR
#define	WS_KERNEL_MONOATTR	WS_DEFAULT_MONOATTR
#endif

#endif /* WSCONS_GLUE */

#endif	/* UWSCONS_H_ */
